@@ -1,7 +1,7 @@
 import os
 import sys
 import logging
-from distlib.database import DistributionPath
+import pkg_resources
 
 TASKS_DIRECTORY = "firex_tasks_directory"
 
@@ -22,36 +22,19 @@ def _get_paths_without_cwd():
 
 
 def _get_firex_dependant_package_locations()-> []:
-    distributions = DistributionPath(path=_get_paths_without_cwd(), include_egg=True).get_distributions()
-
-    # some packages (such as any tree) might cause exceptions in logging
-    old_raise = logging.raiseExceptions
-    try:
-        logging.raiseExceptions = False
-        firex_app_name = __name__.split(".")[0]
-        logging.getLogger('distlib.metadata').setLevel(logging.WARNING)
-        logging.getLogger('distlib.database').setLevel(logging.WARNING)
-        dependants = []
-        while True:
-            try:
-                d = next(distributions)
-            except StopIteration:
-                break
-            except Exception as e:
-                logger.debug(f"Failed to get a distribution due to {e}")
-            else:
-                if firex_app_name in d.run_requires:
-                    dependants.append(d)
-    finally:
-        logging.raiseExceptions = old_raise
+    pkgs = []
+    for package in pkg_resources.WorkingSet():
+        for r in package.requires():
+            if r.project_name == 'firexapp':
+                pkgs.append(package)
 
     locations = []
-    for d in dependants:
-        top = os.path.join(d.path, "top_level.txt")
+    for d in pkgs:
+        top = os.path.join(d.egg_info, "top_level.txt")
         with open(top) as t:
             top_package = t.read().strip()
-            package_location = os.path.join(os.path.dirname(d.path), top_package)
-            locations.append(package_location)
+        package_location = os.path.join(d.location, top_package)
+        locations.append(package_location)
     return locations
 
 
